@@ -8,16 +8,17 @@
 
 
 
-from net_contextdiff import __version__
+from . import __version__
 
 import argparse
 import sys
 
-from deepops import deepmerge, deepget
+from deepops import deepmerge
 import yaml
 
-from net_contextdiff.ios import CiscoIOSConfig, CiscoIOSDiffConfig
-from net_contextdiff.misc import deepselect
+from .ios import CiscoIOSConfig, CiscoIOSDiffConfig
+from .diff import DEBUG_CONVERT_MATCH
+from .misc import deepselect
 
 
 
@@ -121,7 +122,7 @@ def diffconfig(diff, devicename, old_filename, new_filename, output_filename,
     # write the differences to a file or standard output
 
     if output_filename:
-        if debug_convert:
+        if debug_convert > DEBUG_CONVERT_MATCH:
             print("debug: writing to output file:", output_filename)
 
         with open(output_filename, "w") as output_file:
@@ -129,7 +130,7 @@ def diffconfig(diff, devicename, old_filename, new_filename, output_filename,
                 print(diffs, file=output_file)
 
     else:
-        if debug_convert:
+        if debug_convert > DEBUG_CONVERT_MATCH:
             print("debug: writing to standard output")
 
         if diffs:
