@@ -38,10 +38,11 @@ from .misc import deepselect
 # places so it seems sensible to avoid hard coding the values, in case
 # anything changes)
 
-DEBUG_CONVERT_STEPS = 1
-DEBUG_CONVERT_PARAMS = 2
-DEBUG_CONVERT_NODIFF = 3
-DEBUG_CONVERT_NOMATCH = 4
+DEBUG_CONVERT_MATCH = 1
+DEBUG_CONVERT_STEPS = 2
+DEBUG_CONVERT_PARAMS = 3
+DEBUG_CONVERT_NODIFF = 4
+DEBUG_CONVERT_NOMATCH = 5
 
 
 
@@ -1004,16 +1005,18 @@ class DiffConfig:
                 deepremoveitems(d, path_dict)
 
 
-    def _print_debug(self, msg):
+    def _print_debug(self, msg, blank_if_single=True):
         """Print the supplied debugging message followed by a blank
-        line, if it's not empty (in which case, do nothing).
+        line, if it's not empty (in which case, do nothing), unless
+        blank_if_single is True and the message is only one line long.
         """
 
         if msg:
             for line in msg:
                 print(line)
 
-            print()
+            if blank_if_single or (len(msg) > 1):
+                print()
 
 
     def convert(self, old_cfg, new_cfg):
@@ -1177,7 +1180,8 @@ class DiffConfig:
             # currently seem worth doing that for debugging messages
 
             if (self._debug_convert >= DEBUG_CONVERT_NOMATCH
-                or (all_matches and self._debug_convert)):
+                or (all_matches and
+                    self._debug_convert >= DEBUG_CONVERT_STEPS)):
 
 
                 # if we're entering a new block, print a message
@@ -1202,10 +1206,10 @@ class DiffConfig:
                 if match in remove_matches:
                     debug_msg = []
 
-                    if self._debug_convert >= DEBUG_CONVERT_STEPS:
-                        debug_msg += [
+                    if self._debug_convert >= DEBUG_CONVERT_MATCH:
+                        debug_msg.append(
                             "=> remove match: "
-                                + pathstr(match, cvt.wildcard_indices)]
+                                + pathstr(match, cvt.wildcard_indices))
 
 
                     # if we're removing the entire context for this
@@ -1217,7 +1221,10 @@ class DiffConfig:
                             debug_msg.append(
                                 "-> containing context being removed - skip")
 
-                            self._print_debug(debug_msg)
+                            self._print_debug(
+                                debug_msg,
+                                blank_if_single=
+                                    self._debug_convert > DEBUG_CONVERT_MATCH)
 
                         continue
 
@@ -1241,8 +1248,8 @@ class DiffConfig:
                     else:
                         # something remains so this is partial
                         if self._debug_convert >= DEBUG_CONVERT_STEPS:
-                            debug_msg += [
-                                "-> subconfiguration not empty - truncate"]
+                            debug_msg.append(
+                                "-> subconfiguration not empty - truncate")
                         remove_is_truncate = True
 
 
@@ -1256,14 +1263,14 @@ class DiffConfig:
                     cvt_new = cvt.get_cfg(new_cfg, match)
 
                     if self._debug_convert >= DEBUG_CONVERT_PARAMS:
-                        debug_msg += [
+                        debug_msg.append(
                             "-> old configuration:",
-                            yaml.dump(cvt_old, default_flow_style=False)]
+                            yaml.dump(cvt_old, default_flow_style=False))
 
                         if remove_is_truncate:
-                            debug_msg += [
+                            debug_msg.append(
                                 "-> remove configuration:",
-                                yaml.dump(cvt_rem, default_flow_style=False)]
+                                yaml.dump(cvt_rem, default_flow_style=False))
 
 
                     # get elements in the path matching wildcards
@@ -1370,15 +1377,18 @@ class DiffConfig:
                                     " block: %s" % (type(cvt).__name__, t))
 
                             if self._debug_convert >= DEBUG_CONVERT_STEPS:
-                                debug_msg += [
+                                debug_msg.append(
                                     "-> trigger set: %s @ %s"
-                                        % (t, pathstr(match_context, set()))]
+                                        % (t, pathstr(match_context, set())))
 
                             active_triggers.setdefault(t, []).append(
                                 match_context)
 
 
-                    self._print_debug(debug_msg)
+                    self._print_debug(
+                        debug_msg,
+                        blank_if_single=
+                            self._debug_convert > DEBUG_CONVERT_MATCH)
 
 
                 # handle UPDATE conversions, if matching
@@ -1386,10 +1396,10 @@ class DiffConfig:
                 if match in update_matches:
                     debug_msg = []
 
-                    if self._debug_convert >= DEBUG_CONVERT_STEPS:
-                        debug_msg += [
+                    if self._debug_convert >= DEBUG_CONVERT_MATCH:
+                        debug_msg.append(
                             "=> update match: "
-                                + pathstr(match, cvt.wildcard_indices)]
+                                + pathstr(match, cvt.wildcard_indices))
 
 
                     args = cvt.get_wildcard_args(match)
@@ -1421,15 +1431,15 @@ class DiffConfig:
 
                     if self._debug_convert >= DEBUG_CONVERT_PARAMS:
                         if not update_is_add:
-                            debug_msg += [
+                            debug_msg.append(
                                 "-> old configuration:",
                                 yaml.dump(cvt_old, default_flow_style=False),
                                 "-> update configuration:",
-                                yaml.dump(cvt_upd, default_flow_style=False)]
+                                yaml.dump(cvt_upd, default_flow_style=False))
 
-                        debug_msg += [
+                        debug_msg.append(
                             "-> new configuration:",
-                            yaml.dump(cvt_new, default_flow_style=False)]
+                            yaml.dump(cvt_new, default_flow_style=False))
 
 
                     # call the update converter action method
@@ -1503,15 +1513,18 @@ class DiffConfig:
                                     " block: %s" % (type(cvt).__name__, t))
 
                             if self._debug_convert >= DEBUG_CONVERT_STEPS:
-                                debug_msg += [
+                                debug_msg.append(
                                     "-> trigger set: %s @ %s"
-                                        % (t, pathstr(match_context, set()))]
+                                        % (t, pathstr(match_context, set())))
 
                             active_triggers.setdefault(t, []).append(
                                 match_context)
 
 
-                    self._print_debug(debug_msg)
+                    self._print_debug(
+                        debug_msg,
+                        blank_if_single=
+                            self._debug_convert > DEBUG_CONVERT_MATCH)
 
 
                 # handle TRIGGERED conversions, if matching, and this
@@ -1523,11 +1536,11 @@ class DiffConfig:
 
                     debug_msg = []
 
-                    if self._debug_convert >= DEBUG_CONVERT_STEPS:
-                        debug_msg += [
+                    if self._debug_convert >= DEBUG_CONVERT_MATCH:
+                        debug_msg.append(
                             "=> trigger match: %s @ %s"
                                 % (cvt.block,
-                                   pathstr(match, cvt.wildcard_indices))]
+                                   pathstr(match, cvt.wildcard_indices)))
 
 
                     args = cvt.get_wildcard_args(match)
@@ -1541,9 +1554,9 @@ class DiffConfig:
                     cvt_new = cvt.get_cfg(new_cfg, match)
 
                     if self._debug_convert >= DEBUG_CONVERT_PARAMS:
-                        debug_msg += [
+                        debug_msg.append(
                             "-> new configuration:",
-                            yaml.dump(cvt_new, default_flow_style=False)]
+                            yaml.dump(cvt_new, default_flow_style=False))
 
 
                     # call the trigger converter action method
@@ -1590,7 +1603,10 @@ class DiffConfig:
                             debug_msg = []
 
 
-                    self._print_debug(debug_msg)
+                    self._print_debug(
+                        debug_msg,
+                        blank_if_single=
+                            self._debug_convert > DEBUG_CONVERT_MATCH)
 
 
         # if nothing was generated, just return nothing
