@@ -21,8 +21,7 @@ import re
 
 from netaddr import IPNetwork
 
-from net_contextdiff.config import (
-    IndentedContextualCommand, IndentedContextualConfig)
+from ..config import IndentedContextualCommand, IndentedContextualConfig
 
 
 
